@@ -124,6 +124,7 @@ Application::Application(const QString &id, int &argc, char **argv)
     qRegisterMetaType<Log::Msg>("Log::Msg");
 
     setApplicationName("qBittorrent");
+    setOrganizationDomain("qbittorrent.org");
     validateCommandLineParameters();
 
     QString profileDir = m_commandLineArgs.portableMode
@@ -145,6 +146,9 @@ Application::Application(const QString &id, int &argc, char **argv)
 #if !defined(DISABLE_GUI)
     setAttribute(Qt::AA_UseHighDpiPixmaps, true);  // opt-in to the high DPI pixmap support
     setQuitOnLastWindowClosed(false);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+    setDesktopFileName("org.qbittorrent.qBittorrent");
+#endif
 #endif
 
 #if defined(Q_OS_WIN) && !defined(DISABLE_GUI)
