@@ -180,11 +180,14 @@ bool RequestParser::parseRequestLine(const QString &line)
     m_request.method = match.captured(1);
 
     // Request Target
-    const QByteArray decodedUrl {QByteArray::fromPercentEncoding(match.captured(2).toLatin1())};
-    const int sepPos = decodedUrl.indexOf('?');
-    m_request.path = QString::fromUtf8(decodedUrl.constData(), (sepPos == -1 ? decodedUrl.size() : sepPos));
+    // URL components should be separated before percent-decoding
+    // [rfc3986] 2.4 When to Encode or Decode
+    const QByteArray url {match.captured(2).toLatin1()};
+    const int sepPos = url.indexOf('?');
+    const QByteArray pathComponent = ((sepPos == -1) ? url : Utils::ByteArray::midView(url, 0, sepPos));
+    m_request.path = QString::fromUtf8(QByteArray::fromPercentEncoding(pathComponent));
     if (sepPos >= 0)
-        m_request.query = decodedUrl.mid(sepPos + 1);
+        m_request.query = url.mid(sepPos + 1);
 
     // HTTP-version
     m_request.version = match.captured(3);
@@ -200,7 +203,10 @@ bool RequestParser::parsePostMessage(const QByteArray &data)
 
     // application/x-www-form-urlencoded
     if (contentTypeLower.startsWith(CONTENT_TYPE_FORM_ENCODED)) {
-        QListIterator<QStringPair> i(QUrlQuery(data).queryItems(QUrl::FullyDecoded));
+        // [URL Standard] 5.1 application/x-www-form-urlencoded parsing
+        const QByteArray processedData = QByteArray(data).replace('+', ' ');
+
+        QListIterator<QStringPair> i(QUrlQuery(processedData).queryItems(QUrl::FullyDecoded));
         while (i.hasNext()) {
             const QStringPair pair = i.next();
             m_request.posts[pair.first] = pair.second;
