@@ -292,10 +292,6 @@
         <source>qBittorrent client is not reachable</source>
         <translation>qBittorrent-klienten kan ikke kontaktes</translation>
     </message>
-    <message>
-        <source>qBittorrent has been shutdown.</source>
-        <translation type="vanished">qBittorrent er blevet lukket ned.</translation>
-    </message>
     <message>
         <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
         <translation>Global græse for antal uploadpladser skal være større end 0 eller deaktiveret.</translation>
@@ -334,6 +330,10 @@
     </message>
     <message>
         <source>qBittorrent has been shutdown</source>
+        <translation>qBittorrent er blevet lukket ned</translation>
+    </message>
+    <message>
+        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
         <translation type="unfinished" />
     </message>
 </context>
