@@ -292,10 +292,6 @@
         <source>qBittorrent client is not reachable</source>
         <translation>qBittorrent-Programm ist nicht erreichbar</translation>
     </message>
-    <message>
-        <source>qBittorrent has been shutdown.</source>
-        <translation type="vanished">qBittorrent wurde beendet.</translation>
-    </message>
     <message>
         <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
         <translation>Die Gesamtanzahl der Upload-Slots muss größer als 0 sein oder deaktiviert werden.</translation>
@@ -334,6 +330,10 @@
     </message>
     <message>
         <source>qBittorrent has been shutdown</source>
+        <translation>qBittorrent wurde beendet</translation>
+    </message>
+    <message>
+        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
         <translation type="unfinished" />
     </message>
 </context>
