@@ -292,10 +292,6 @@
         <source>qBittorrent client is not reachable</source>
         <translation>Klient qBittorrent jest nieosiągalny</translation>
     </message>
-    <message>
-        <source>qBittorrent has been shutdown.</source>
-        <translation type="vanished">qBittorrent został zamknięty.</translation>
-    </message>
     <message>
         <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
         <translation>Ogólna liczba limitu slotów wysyłania musi być większy od 0 lub wyłączona.</translation>
@@ -334,6 +330,10 @@
     </message>
     <message>
         <source>qBittorrent has been shutdown</source>
+        <translation>qBittorrent został zamknięty</translation>
+    </message>
+    <message>
+        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
         <translation type="unfinished" />
     </message>
 </context>
